@@ -50,3 +50,19 @@ where
         }
     }
 }
+
+/// get input or if failed then return with the default value
+pub fn input_other_or<T>(output: &str, default: T) -> T
+where
+    T: FromStr,
+{
+    input(output).trim().parse::<T>().unwrap_or(default)
+}
+
+/// get input or if failed then return with the default value
+pub fn input_other_or_else<T, F: FnOnce() -> T>(output: &str, func: F) -> T
+where
+    T: FromStr,
+{
+    input_other_or(output, func())
+}
